@@ -10,20 +10,20 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from openstack.network import network_service
-from openstack import resource2 as resource
+from openstack import resource
 
 
 class HealthMonitor(resource.Resource):
     resource_key = 'healthmonitor'
     resources_key = 'healthmonitors'
     base_path = '/lbaas/healthmonitors'
-    service = network_service.NetworkService()
+
+    _allow_unknown_attrs_in_body = True
 
     # capabilities
     allow_create = True
-    allow_get = True
-    allow_update = True
+    allow_fetch = True
+    allow_commit = True
     allow_delete = True
     allow_list = True
 
@@ -51,6 +51,8 @@ class HealthMonitor(resource.Resource):
     #: List of pools associated with this health monitor
     #: *Type: list of dicts which contain the pool IDs*
     pool_ids = resource.Body('pools', type=list)
+    #: The ID of the pool associated with this health monitor
+    pool_id = resource.Body('pool_id')
     #: The ID of the project this health monitor is associated with.
     project_id = resource.Body('tenant_id')
     #: The maximum number of seconds for a monitor to wait for a
